Subject: [PATCH 1/2] gnu: pypandoc: Update to 1.13 and fix dependencies
From: Aaron Covrig <[email-masked]>
To: [email-masked]
Cc: Aaron Covrig <[email-masked]>
Date: Wed, 18 Sep 2024 17:14:50 -0400
List-Id: <debbugs-submit.debbugs.gnu.org>

* gnu/packages/python-xyz.scm (pypandoc): Update to 1.13
[inputs]: Add texlive-xpatch
---
 gnu/packages/python-xyz.scm | 39 ++++++++++++++++++++-----------------
 1 file changed, 21 insertions(+), 18 deletions(-)

diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 8d402d4f94..055faef0de 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -155,6 +155,7 @@
 ;;; Copyright © 2024 David Elsing <[email-masked]>
 ;;; Copyright © 2024 Rick Huijzer <[email-masked]>
 ;;; Copyright © 2024 Peter Kannewitz <[email-masked]>
+;;; Copyright © 2024 Aaron Covrig <[email-masked]>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -32381,31 +32382,33 @@ (define-public python-safety
 (define-public python-pypandoc
   (package
     (name "python-pypandoc")
-    (version "1.7.5")
+    (version "1.13")
     (source
      (origin
        (method url-fetch)
        (uri (pypi-uri "pypandoc" version))
        (sha256
-        (base32
-         "0l6a8ngzpx363q2jskxxkx6psfhqrvc4js80dmn16r3vw6m2cb40"))))
+        (base32 "07hw2psqzaffskmgb789f0zbra9cc17ykl8baw1jn34nqxrj0r9i"))))
     (build-system python-build-system)
-    (inputs
-     (list pandoc python-pandocfilters))
-    (propagated-inputs
-     `(("wheel" ,python-wheel)))
-    (native-inputs
-     `(("texlive" ,(texlive-updmap.cfg (list texlive-lm texlive-xcolor)))))
+    (inputs (list pandoc python-pandocfilters texlive-xpatch))
+    (propagated-inputs `(("wheel" ,python-wheel)))
+    (native-inputs `(("texlive" ,(texlive-updmap.cfg (list texlive-lm
+                                                           texlive-xcolor)))))
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-before 'check 'disable-tests
-           (lambda _
-             ;; Disable test requiring network access
-             (substitute* "tests.py"
-               (("test_basic_conversion_from_http_url")
-                "skip_test_basic_conversion_from_http_url"))
-             #t)))))
+     `(#:phases (modify-phases %standard-phases
+                  (add-before 'check 'disable-tests
+                    (lambda _
+                      (substitute* "tests.py"
+                        ;; Disable test requiring network access
+                        (("test_basic_conversion_from_http_url")
+                         "skip_test_basic_conversion_from_http_url")
+                        ;; Disable tests with missing files
+                        (("test_basic_conversion_from_file_pattern")
+                         "skip_test_basic_conversion_from_file_pattern")
+                        (("test_conversion_with_data_files")
+                         "skip_test_conversion_with_data_files")
+                        (("test_conversion_stderr")
+                         "skip_test_conversion_stderr")) #t)))))
     (home-page "https://github.com/bebraw/pypandoc")
     (synopsis "Python wrapper for pandoc")
     (description "pypandoc is a thin Python wrapper around pandoc

base-commit: 1b6ce1796abdf497f61f426d61339318f4f4f23d
-- 
2.46.0